faker\_file.providers.base package
==================================

Submodules
----------

faker\_file.providers.base.image\_generator module
--------------------------------------------------

.. automodule:: faker_file.providers.base.image_generator
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.base.mp3\_generator module
------------------------------------------------

.. automodule:: faker_file.providers.base.mp3_generator
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.base.pdf\_generator module
------------------------------------------------

.. automodule:: faker_file.providers.base.pdf_generator
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.base.text\_augmenter module
-------------------------------------------------

.. automodule:: faker_file.providers.base.text_augmenter
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.base.text\_extractor module
-------------------------------------------------

.. automodule:: faker_file.providers.base.text_extractor
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: faker_file.providers.base
   :members:
   :undoc-members:
   :show-inheritance:
